pub struct PoolStore { /* private fields */ }Implementations
Sourceimpl PoolStore
impl PoolStore
pub fn maintain( &self, max_items: usize, ) -> Result<PoolMaintenanceReport, StoreError>
Sourceimpl PoolStore
impl PoolStore
pub fn balance_temperature(&self) -> Result<PoolTemperatureReport, StoreError>
Sourceimpl PoolStore
impl PoolStore
pub fn open<P: AsRef<Path>>( path: P, config: PoolStoreConfig, ) -> Result<Self, StoreError>
pub fn add_member( &self, config: PoolMemberConfig, ) -> Result<PoolMemberId, StoreError>
pub fn begin_drain(&self, id: PoolMemberId) -> Result<(), StoreError>
pub fn update_member_limits( &self, id: PoolMemberId, capacity_bytes: u64, max_read_concurrency: u32, max_write_concurrency: u32, ) -> Result<(), StoreError>
pub fn update_member_temperature_watermarks( &self, id: PoolMemberId, low_percent: u8, high_percent: u8, ) -> Result<(), StoreError>
pub fn remove_member(&self, id: PoolMemberId) -> Result<(), StoreError>
pub fn member(&self, id: PoolMemberId) -> Result<PoolMemberStatus, StoreError>
pub fn members(&self) -> Result<Vec<PoolMemberStatus>, StoreError>
pub fn blob_location( &self, hash: &Hash, ) -> Result<Option<PoolMemberId>, StoreError>
pub fn put_sync(&self, hash: Hash, data: &[u8]) -> Result<bool, StoreError>
pub fn put_many_report_sync( &self, items: &[(Hash, Vec<u8>)], ) -> Result<PutManyReport, StoreError>
pub fn put_many_sync( &self, items: &[(Hash, Vec<u8>)], ) -> Result<usize, StoreError>
pub fn get_sync(&self, hash: &Hash) -> Result<Option<Vec<u8>>, StoreError>
pub fn get_range_sync( &self, hash: &Hash, start: u64, end_inclusive: u64, ) -> Result<Option<Vec<u8>>, StoreError>
pub fn blob_size_sync(&self, hash: &Hash) -> Result<Option<u64>, StoreError>
pub fn exists(&self, hash: &Hash) -> Result<bool, StoreError>
pub fn existing_hashes_in_sorted_candidates( &self, sorted_hashes: &[Hash], ) -> Result<Vec<bool>, StoreError>
Sourcepub fn largest_member_map_size_bytes(&self) -> Result<Option<usize>, StoreError>
pub fn largest_member_map_size_bytes(&self) -> Result<Option<usize>, StoreError>
Largest map size among members that are available in this process.
The pool catalog is a separate LMDB environment and is intentionally not reported as blob capacity.
pub fn delete_sync(&self, hash: &Hash) -> Result<bool, StoreError>
pub fn pin_sync(&self, hash: &Hash) -> Result<(), StoreError>
pub fn unpin_sync(&self, hash: &Hash) -> Result<(), StoreError>
pub fn pin_count_sync(&self, hash: &Hash) -> Result<u32, StoreError>
pub fn touch_accessed_sync( &self, hash: &Hash, now: u64, ) -> Result<bool, StoreError>
pub fn touch_many_accessed_sync( &self, hashes: &[Hash], now: u64, ) -> Result<usize, StoreError>
pub fn last_accessed_at_sync( &self, hash: &Hash, ) -> Result<Option<u64>, StoreError>
pub fn many_last_accessed_at_sync( &self, hashes: &[Hash], ) -> Result<Vec<(Hash, u64)>, StoreError>
pub fn list(&self) -> Result<Vec<Hash>, StoreError>
pub fn stats(&self) -> Result<StoreStats, StoreError>
pub fn force_sync(&self) -> Result<(), StoreError>